unittest.TestProgram

unittest :: TestProgram :: Class TestProgram |
[hide private]
[frames] | no frames]

# Class TestProgram

source code

    object --+
             |
            TestProgram

A command-line program that runs a set of tests; this is primarily for making test modules conveniently executable.

Instance Methods | [hide private]
__init__(self, module=`'``__main__``'`, defaultTest=None, argv=None, testRunner=None, testLoader=<unittest.TestLoader object at 0xf98590>) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
createTests(self) | source code
parseArgs(self, argv) | source code
runTests(self) | source code
usageExit(self, msg=None) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
| USAGE = ``'``Usage: %(progName)s [options] [test] [...]\n\nOptions``...``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, module=`'``__main__``'`, defaultTest=None, argv=None, testRunner=None, testLoader=<unittest.TestLoader object at 0xf98590>) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

Class Variable Details | [hide private]

  ### USAGE Value:
      '''Usage: %(progName)s [options] [test] [...]

      Options:
        -h, --help       Show this message
        -v, --verbose    Verbose output
        -q, --quiet      Minimal output

      Examples:
      ...